==> ksystemlog-21.03.90.tar.xz: ksystemlog-21.03.90/src/lib/logModeConfiguration.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef LOG_MODE_CONFIGURATION_H
#define LOG_MODE_CONFIGURATION_H

#include <QList>
#include <QObject>
#include <QStringList>

#include "logFile.h"

class KSystemLogConfig;

class LogModeConfiguration : public QObject
{
    Q_OBJECT

public:
    explicit LogModeConfiguration(QObject *parent = nullptr);

    ~LogModeConfiguration() override;

    LogFile findGenericLogFile(const QString &file);
    QVector<LogFile> findGenericLogFiles(const QStringList &files);

    QVector<LogFile> findNoModeLogFiles(const QStringList &stringList);

protected:
    KSystemLogConfig *mConfiguration = nullptr;
};

#endif // _LOG_MODE_CONFIGURATION_H

==> ksystemlog_21.08.1.orig.tar.xz: ksystemlog-21.08.1/src/lib/logModeConfiguration.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#pragma once

#include <QList>
#include <QObject>
#include <QStringList>

#include "logFile.h"

class KSystemLogConfig;

class LogModeConfiguration : public QObject
{
    Q_OBJECT

public:
    explicit LogModeConfiguration(QObject *parent = nullptr);

    ~LogModeConfiguration() override;

    LogFile findGenericLogFile(const QString &file);
    QVector<LogFile> findGenericLogFiles(const QStringList &files);

    QVector<LogFile> findNoModeLogFiles(const QStringList &stringList);

protected:
    KSystemLogConfig *mConfiguration = nullptr;
};
